@@ -36,13 +36,19 @@ Dico DictParts(int m, int n) {
 }
 
 Eigen::ArrayXi cleanPart(Eigen::ArrayXi& kappa) {
-  std::vector<int> vout(0);
   int n = kappa.size();
+  if(n == 0){
+    return {};
+  }
+  std::vector<int> vout(0);
   int i = 0;
   while(i < n && kappa.coeff(i) > 0) {
     vout.push_back(kappa.coeff(i));
     i++;
   }
+  if(i == 0){
+    return {};
+  }
   int* ptr_data = &vout[0];
   return Eigen::Map<Eigen::ArrayXi, Eigen::Unaligned>(ptr_data, vout.size());
 }
